Enum emerald_rocksdb::compaction_filter::Decision
[−]
[src]
pub enum Decision {
Keep,
Remove,
Change(&'static [u8]),
}Decision about how to handle compacting an object
This is returned by a compaction filter callback. Depending on the value, the object may be kept, removed, or changed in the database during a compaction.
Variants
KeepKeep the old value
RemoveRemove the object from the database
Change(&'static [u8])Change the value for the key